Research projects — version 1.0.0

# Research projects

The model has being used in these research projects:

- Flexible electric demand management in markets with high penetration of renewable sources (DEFINER), developed for the Ministry of Science and Innovation/State Research Agency (10.13039/501100011033) under the program Public-Private Partnerships with NextGenerationEU/PRTR funds (CPP2021-008786). December 2022 - November 2025. A. Ramos, J.M. Latorre, P. Sanchez, E.F. Álvarez, P. Rodilla, P. Mastropietro, C. Batlle, A. Bello, D.M. Navarrete